﻿

/**
 * This enum holds information of acquisition type.
 */
export enum CharacteristicType {
    /// <summary>
    /// Variable property type
    /// </summary>
    VAR = 1,

    /// <summary>
    /// Attributive property type
    /// </summary>
    ATT = 2,

    /// <summary>
    /// Visual property type
    /// </summary>
    VIS = 3
}

/**
 * This class holds information of acquisition step.
 */
export class AcquisitionStepModel {

    PropertyDescription: string;
    PropertyNo: string;
    CharacteristicID: number;
    CharacteristicRevision: number;
    CharacteristicSpecificationNo: number;
    SortingNo: number;
    InspectionOrderStepID: number;
    AmountOfParts: number;
    AcquisitionStepNoInGroup: number;
    DefectIndex: number;
    DefectNo: string;
    DefectText: string;
    ToolID: number;
    ToolText: string;
    LowerTolerance: number;
    UpperTolerance: number;
    Measurement: number;
    DecimalPlaces: number;
    AcquisitionType: number;
    AcquisitionStepNo: number;
    InspectionStepID: number;
    InspectionOrderID: number;
    InspectionOrderSequence: number;
    DefectID: number;
    AcquisitionTimestamp: Date;
    AcquisitionUser: string;
    AcquisitionUserID: number;
    StationNo: string;
    StationID: number;
    InspectionSequenceType: number;
    InspectionSequence: number;
    NominalValue: number;
    InspectionType: number;
    InspectionPlanRevisionID: number;
    CharacteristicType: CharacteristicType;
    PartNo: number;
    LowerToleranceAbsolute: number;
    UpperToleranceAbsolute: number;
    DerivedFromGroupPlan: boolean;
    ControlChartTypeID: number;
    SampleSize: number;
    PassDefinition: string;
    FailDefinition: string;

    GaugeID: number;
    GaugeGroupID: number;
    GaugeNo: string;
    GaugeDescription: string;

    DefectCount: number;
    IO: number;
    NIO: number;
    ACQValue: number;

    // TODO : Kaustubh - Check if this can be merged with DefectText and PropertyDescription
    Description: string;
    VarDescription: string;

    ChartValue: string;
    AcqStepCount: number;

    UniqueID: number;
    GroupIndex: number; // Index of parent group.
}

/**
 * This class holds information about additional acquisition data.
 */
export class AdditionalAcquisitionData {
    //Additional information(strings)
    AdditionalInfo01: string;
    AdditionalInfo02: string;
    AdditionalInfo03: string;
    AdditionalInfo04: string;
    AdditionalInfo05: string;
    AdditionalInfo06: string;
    AdditionalInfo07: string;
    AdditionalInfo08: string;
    AdditionalInfo09: string;
    AdditionalInfo10: string;
    AdditionalInfo11: string;
    AdditionalInfo12: string;
    AdditionalInfo13: string;
    AdditionalInfo14: string;
    AdditionalInfo15: string;
    AdditionalInfo16: string;
    AdditionalInfo17: string;
    AdditionalInfo18: string;
    AdditionalInfo19: string;
    AdditionalInfo20: string;
    AdditionalInfo21: string;
    AdditionalInfo22: string;
    AdditionalInfo23: string;
    AdditionalInfo24: string;
    AdditionalInfo25: string;
    AdditionalInfo26: string;
    AdditionalInfo27: string;
    AdditionalInfo28: string;

    //Additional information (numbers)
    AdditionalNumber29: number;
    AdditionalNumber30: number;
    AdditionalNumber31: number;
    AdditionalNumber32: number;
    AdditionalNumber33: number;
    AdditionalNumber34: number;
    AdditionalNumber35: number;
    AdditionalNumber36: number;

    //Additional information (date time)
    AdditionalDate37: Date;
    AdditionalDate38: Date;
    AdditionalDate39: Date;
    AdditionalDate40: Date;

    BatchID: number;
    LotID: number;

    /**
     * constructor
     */
    constructor() {

    }
}

/**
 * Settings for Acquisition Group
 */
export class AcquisitionGroupSettings {
    ShowInspectionInstruction: boolean;
}

/**
 * This class holds information of acquisition group.
 */
export class AcquisitionGroupModel {
    AcquisitionSteps: AcquisitionStepModel[]
    CountOfAcquisitionSteps: number;
    AdditionalAcquisitionData: AdditionalAcquisitionData;
    Settings: AcquisitionGroupSettings;
    InspectionInstruction: string;
    GroupIndex: number;

    // TODO : Kaustubh - Check if this can be calculated by using steps.
    AcqStatus: string;
    Value: number;
    Chart: string;

    // TODO : Kaustubh - Calculate from CharacteristicType of step.
    Type: CharacteristicType;

    CharDesc: string;
    InspectionOrderStepId: number;

    /**
     * constructor
     */
    constructor() {
        this.AcquisitionSteps = new Array<AcquisitionStepModel>();
        this.AdditionalAcquisitionData = new AdditionalAcquisitionData();
        this.Settings = new AcquisitionGroupSettings();
    }
}