﻿/**
 * Interface for updating UI element of table.
 */
export interface IUiElement {
    rowID: number;
    value: number;

    // Method to update row data.
    updateRow(jsonObj: any);

    // Method to update parent row data.
    updateParentRow(jsonObj: any);
}

/**
 * Class to represent UI element of cell.
 */
export class Ui implements IUiElement {

    rowID: number;
    value: number;

    private gridId: string;
    private parentRowID: number;

    /**
     * Constructor.
     * @param ui
     * @param parentGridName
     */
    constructor(private ui: any, parentGridName: any, parentRowID: number = null) {
        this.gridId = parentGridName;
        if (ui != undefined) {
            if (ui.rowID == undefined || ui.rowID == null)
                this.rowID = ui.row.id;
            else
                this.rowID = ui.rowID;
            this.value = ui.value;
        }
        else
            this.rowID = parentRowID;
        
        //var parentRow = this.ui.owner.grid.element.closest("tr").prev();
        this.parentRowID = parentRowID;//parseInt(parentRow.attr("data-id"));
    }

    /**
     * Updates row data.
     * @param jsonObj
     */
    updateRow(jsonObj: any) {
        this.ui.owner.updateRow(this.rowID, jsonObj);
    }

    /**
     * Updates parent row data.
     * @param jsonObj
     */
    updateParentRow(jsonObj: any) {
        $(this.gridId).igGridUpdating("updateRow", this.parentRowID, jsonObj);
    }
}

/**
 * Class to represent UI element of row.
 */
export class RowElement implements IUiElement {

    rowID: number;
    value: number;

    private gridId: string;
    private childGridId: string;

    /**
     * Constructor.
     * @param parentRowId
     * @param rowId
     * @param value
     * @param gridName
     */
    constructor(private parentRowId: number,
        private rowId: number,
        value: number,
        gridName: string) {
        this.gridId = "#" + gridName;
        this.childGridId = "#hgrid1_" + parentRowId + "_AcquisitionSteps_child";
        this.rowID = rowId;
        this.value = value;
    }

    /**
     * Updates row data.
     * @param jsonObj
     */
    updateRow(jsonObj: any) {
        $(this.childGridId).igGridUpdating("updateRow", this.rowID, jsonObj);
    }

    /**
     * Updates parent row data.
     * @param jsonObj
     */
    updateParentRow(jsonObj: any) {
        $(this.gridId).igGridUpdating("updateRow", this.parentRowId, jsonObj);
    }
}