import { Component, Input, DynamicComponentLoader, Injector, ElementRef, ViewChild } from '@angular/core';
//import { igGrid } from 'igniteui-angular2';
import {AttTableComponent} from './sub-component/att-table.component';
import {VisTableComponent} from './sub-component/vis-table.component';
import {VarTableComponent} from './sub-component/var-table.component';
import { AcquisitionGroupModel, AcquisitionStepModel, CharacteristicType } from './model/acquisitionGroup.model';
import { BaseComponent } from './baseComponent';


declare var jQuery: any;
var ACQType = [{ "type": "VAR" }, { "type": "ATT" }, {"type": "VIS"}]


@Component({
    selector: 'my-app',
    template: `
                    <div class="row component">
                        <div class="col-md-12">
                            <table id="gridId" class="table-font-size" ></table>
                            <div *ngFor="let item of sourceData; let i = index">
                                <div [ngSwitch]="item.Type">
                                    <var-table *ngSwitchCase="1" id="childGrid_{{i}}" [(source)]="item.AcquisitionSteps" [(data)]="sourceData" [maxDecimalVal]="maxDecimalVal" (change)="UpdateParent($event)" (move)="moveToNextTable($event)"></var-table>
                                    <att-table *ngSwitchCase="2" id="childGrid_{{i}}" [(source)]="item.AcquisitionSteps" [(data)]="sourceData" (change)="UpdateParent($event)" (move)="moveToNextTable($event)" ></att-table>
                                    <vis-table *ngSwitchCase="3" id="childGrid_{{i}}" [(source)]="item.AcquisitionSteps" [(data)]="sourceData" (change)="UpdateParent($event)" (move)="moveToNextTable($event)" ></vis-table>
                                    <div *ngSwitchDefault></div>
                                </div>
                            </div>
                        </div>
                    </div>
                 `,
    directives: [ AttTableComponent, VisTableComponent, VarTableComponent],
    //providers:[IteratorService, AcquisitionTableUpdateService]
})
export class AppComponent extends BaseComponent {
    // Input variables
    @Input() orderid: number;

    // Private variables
   
    private gridId: string;
    private sourceData: any;
    private selectedRowId: number;
    private selectedUiObj: any;
    private tempAgt: any;
    private maxDecimalVal: number;
    // Type of acquisition group. Default value is None.
    private groupType: CharacteristicType;
    private source: any;

    @ViewChild(AttTableComponent) private childAtt: AttTableComponent;
    @ViewChild(VisTableComponent) private childVis: VisTableComponent;
    @ViewChild(VarTableComponent) private childVar: VarTableComponent;

    attachChildGridEvents() {
        var that = this;
        $("#gridId").on("iggridselectionrowselectionchanged", function (evt, ui) {
            that.selectedUiObj = ui;
            that.selectedRowId = ui.row.id;
            console.log("Selected Index : " + that.selectedRowId);
            that.showOnlySelected(that.selectedRowId);
        });
        $("#gridId").on("iggridselectionactiverowchanged", function (evt, ui) {
            console.log("-----------------------iggridselectionactiverowchanged----------");
            if (ui.row != null) {
                that.selectedUiObj = ui;
                that.selectedRowId = ui.row.id;
                console.log(ui);
            }
        });
    }

    private showOnlySelected(index) {
        index -= 1;
        document.getElementById("childGrid_" + index).style.display = "block";
        for (let i = 0; i < this.sourceData.length; i++) {
            if (i == index) {
                if (this.sourceData[i].Type == 2)
                    this.childAtt.showEditMode();
                if (this.sourceData[i].Type == 1)
                    this.childVar.showEditMode();
                if (this.sourceData[i].Type == 3)
                    this.childVis.showEditMode();
                continue;
            }
            document.getElementById("childGrid_" + i).style.display = "none";
        }
    }
    createInfraTable() {
        let that = this;
        $("#gridId").igGrid({
            autoCommit: false,
            alternateRowStyles: true,
            dataSource: this.sourceData,
            width: "100%",
            //height:"460px",
            autoGenerateColumns: false,
            dataSourceType: "json",
            autoGenerateColumnLayouts: false,
            primaryKey: "GroupIndex",
            columns: [
                { key: "Chart", headerText: "", width: "10%", dataType: "string" },
                { key: "GroupIndex", headerText: "ACQUISITION GROUP NR.", width: "22%", dataType: "number" },
                { key: "Type", headerText: "TYPE", width: "10%", dataType: "string", columnCssClass: "acqtype-column-val", formatter: this.formatGroupType },
                { key: "CountOfAcquisitionSteps", headerText: "AMOUNT STEPS", width: "15%", dataType: "number" },
                { key: "AcqStatus", headerText: "COMPLETE", width: "12%", dataType: "string" },
                { key: "Value", headerText: "AVERAGE", width: "12%", dataType: "string", columnCssClass: "acqtype-column-val" },
                { key: "CharDesc", headerText: "DESCRIPTION", width: "8%", dataType: "string" }
            ],
            features: [
                {
                    name: "Selection",
                    mode: "row",
                },
                {
                    name: "Updating", editMode: "none", enableAddRow: false, enableDeleteRow: false, showDoneCancelButtons: false,
                    columnSettings: [
                        { columnKey: "Chart", editorType: "string", readOnly: true },
                        { columnKey: "GroupIndex", editorType: "numeric", readOnly: true },
                        { columnKey: "Type", editorType: "string", readOnly: true },
                        { columnKey: "CountOfAcquisitionSteps", editorType: "numeric", readOnly: true },
                        { columnKey: "AcqStatus", editorType: "string", readOnly: true },
                        { columnKey: "Value", editorType: "string", readOnly: true },
                        { columnKey: "CharDesc", editorType: "string", readOnly: true }]
                },

            ]
        });
    }

    ngOnInit() {
        this.initializeTable(); 
        this.createInfraTable();
        this.attachChildGridEvents()
        setTimeout(()=>{this.showOnlySelected(1);}, 1000);
    }
        
    constructor()
     {
        super();
        this.selectedRowId = undefined;
        this.selectedUiObj = undefined;
        this.sourceData = new Array<AcquisitionGroupModel>();
        this.tempAgt = new Array<AcquisitionGroupModel>();
     }

    initializeTable() {
        this.sourceData = [
	    {
		"$type": "Ibs.Inspection.Model.AcquisitionGroupModel, Ibs.Inspection.Model",
		"AcqStatus": "No",
		"AcquisitionSteps": [{
			"$type": "Ibs.Inspection.Model.AcquisitionStepModel, Ibs.Inspection.Model",
			"ACQValue": null,
			"AcqStepCount": 5,
			"AcquisitionStepNo": 1,
			"AcquisitionStepNoInGroup": 1,
			"AcquisitionTimestamp": "0001-01-01T00:00:00",
			"AcquisitionType": 1,
			"AcquisitionUser": null,
			"AcquisitionUserID": 0,
			"AmountOfParts": 0,
			"CharacteristicID": 7001,
			"CharacteristicRevision": 1,
			"CharacteristicSpecificationNo": 1,
			"CharacteristicType": 1,
			"ChartValue": "<div class = 'line-color-notdone' ></div>",
			"ControlChartTypeID": 1,
			"DateOfSample": "0001-01-01T00:00:00",
			"DecimalPlaces": 4,
			"DefectCount": null,
			"DefectID": 0,
			"DefectIndex": 0,
			"DefectNo": null,
			"DefectText": null,
			"DerivedFromGroupPlan": false,
			"Description": "Var 1",
			"FailDefinition": "",
			"IO": null,
			"InspectionOrderID": 1001,
			"InspectionOrderSequence": 1,
			"InspectionOrderStepID": 1001,
			"InspectionPlanRevisionID": 4,
			"InspectionSequence": 0,
			"InspectionSequenceType": 0,
			"InspectionStepID": 4001,
			"InspectionType": 4,
			"LowerTolerance": 45.5,
			"LowerToleranceAbsolute": 45.5,
			"Measurement": null,
			"NIO": null,
			"NominalValue": 50,
			"PartNo": 1,
			"PassDefinition": "",
			"PropertyDescription": "Var 1",
			"PropertyNo": "MCT 10",
			"SampleSize": 5,
			"SortingNo": 1,
			"StationID": 0,
			"StationNo": null,
			"ToolID": 1,
			"ToolText": "",
			"UniqueID": 1,
			"UpperTolerance": 54.5,
			"UpperToleranceAbsolute": 54.5,
			"VarDescription": "Var 1"
		}, {
			"$type": "Ibs.Inspection.Model.AcquisitionStepModel, Ibs.Inspection.Model",
			"ACQValue": null,
			"AcqStepCount": 5,
			"AcquisitionStepNo": 1,
			"AcquisitionStepNoInGroup": 1,
			"AcquisitionTimestamp": "0001-01-01T00:00:00",
			"AcquisitionType": 1,
			"AcquisitionUser": null,
			"AcquisitionUserID": 0,
			"AmountOfParts": 0,
			"CharacteristicID": 7001,
			"CharacteristicRevision": 1,
			"CharacteristicSpecificationNo": 1,
			"CharacteristicType": 1,
			"ChartValue": "<div class = 'line-color-notdone' ></div>",
			"ControlChartTypeID": 1,
			"DateOfSample": "0001-01-01T00:00:00",
			"DecimalPlaces": 4,
			"DefectCount": null,
			"DefectID": 0,
			"DefectIndex": 0,
			"DefectNo": null,
			"DefectText": null,
			"DerivedFromGroupPlan": false,
			"Description": "Var 1",
			"FailDefinition": "",
			"IO": null,
			"InspectionOrderID": 1001,
			"InspectionOrderSequence": 1,
			"InspectionOrderStepID": 1001,
			"InspectionPlanRevisionID": 4,
			"InspectionSequence": 0,
			"InspectionSequenceType": 0,
			"InspectionStepID": 4001,
			"InspectionType": 4,
			"LowerTolerance": 45.5,
			"LowerToleranceAbsolute": 45.5,
			"Measurement": null,
			"NIO": null,
			"NominalValue": 50,
			"PartNo": 1,
			"PassDefinition": "",
			"PropertyDescription": "Var 1",
			"PropertyNo": "MCT 10",
			"SampleSize": 5,
			"SortingNo": 1,
			"StationID": 0,
			"StationNo": null,
			"ToolID": 1,
			"ToolText": "",
			"UniqueID": 2,
			"UpperTolerance": 54.5,
			"UpperToleranceAbsolute": 54.5,
			"VarDescription": "Var 1"
		}, {
			"$type": "Ibs.Inspection.Model.AcquisitionStepModel, Ibs.Inspection.Model",
			"ACQValue": null,
			"AcqStepCount": 5,
			"AcquisitionStepNo": 1,
			"AcquisitionStepNoInGroup": 1,
			"AcquisitionTimestamp": "0001-01-01T00:00:00",
			"AcquisitionType": 1,
			"AcquisitionUser": null,
			"AcquisitionUserID": 0,
			"AmountOfParts": 0,
			"CharacteristicID": 7001,
			"CharacteristicRevision": 1,
			"CharacteristicSpecificationNo": 1,
			"CharacteristicType": 1,
			"ChartValue": "<div class = 'line-color-notdone' ></div>",
			"ControlChartTypeID": 1,
			"DateOfSample": "0001-01-01T00:00:00",
			"DecimalPlaces": 4,
			"DefectCount": null,
			"DefectID": 0,
			"DefectIndex": 0,
			"DefectNo": null,
			"DefectText": null,
			"DerivedFromGroupPlan": false,
			"Description": "Var 1",
			"FailDefinition": "",
			"IO": null,
			"InspectionOrderID": 1001,
			"InspectionOrderSequence": 1,
			"InspectionOrderStepID": 1001,
			"InspectionPlanRevisionID": 4,
			"InspectionSequence": 0,
			"InspectionSequenceType": 0,
			"InspectionStepID": 4001,
			"InspectionType": 4,
			"LowerTolerance": 45.5,
			"LowerToleranceAbsolute": 45.5,
			"Measurement": null,
			"NIO": null,
			"NominalValue": 50,
			"PartNo": 1,
			"PassDefinition": "",
			"PropertyDescription": "Var 1",
			"PropertyNo": "MCT 10",
			"SampleSize": 5,
			"SortingNo": 1,
			"StationID": 0,
			"StationNo": null,
			"ToolID": 1,
			"ToolText": "",
			"UniqueID": 3,
			"UpperTolerance": 54.5,
			"UpperToleranceAbsolute": 54.5,
			"VarDescription": "Var 1"
		}, {
			"$type": "Ibs.Inspection.Model.AcquisitionStepModel, Ibs.Inspection.Model",
			"ACQValue": null,
			"AcqStepCount": 5,
			"AcquisitionStepNo": 1,
			"AcquisitionStepNoInGroup": 1,
			"AcquisitionTimestamp": "0001-01-01T00:00:00",
			"AcquisitionType": 1,
			"AcquisitionUser": null,
			"AcquisitionUserID": 0,
			"AmountOfParts": 0,
			"CharacteristicID": 7001,
			"CharacteristicRevision": 1,
			"CharacteristicSpecificationNo": 1,
			"CharacteristicType": 1,
			"ChartValue": "<div class = 'line-color-notdone' ></div>",
			"ControlChartTypeID": 1,
			"DateOfSample": "0001-01-01T00:00:00",
			"DecimalPlaces": 4,
			"DefectCount": null,
			"DefectID": 0,
			"DefectIndex": 0,
			"DefectNo": null,
			"DefectText": null,
			"DerivedFromGroupPlan": false,
			"Description": "Var 1",
			"FailDefinition": "",
			"IO": null,
			"InspectionOrderID": 1001,
			"InspectionOrderSequence": 1,
			"InspectionOrderStepID": 1001,
			"InspectionPlanRevisionID": 4,
			"InspectionSequence": 0,
			"InspectionSequenceType": 0,
			"InspectionStepID": 4001,
			"InspectionType": 4,
			"LowerTolerance": 45.5,
			"LowerToleranceAbsolute": 45.5,
			"Measurement": null,
			"NIO": null,
			"NominalValue": 50,
			"PartNo": 1,
			"PassDefinition": "",
			"PropertyDescription": "Var 1",
			"PropertyNo": "MCT 10",
			"SampleSize": 5,
			"SortingNo": 1,
			"StationID": 0,
			"StationNo": null,
			"ToolID": 1,
			"ToolText": "",
			"UniqueID": 4,
			"UpperTolerance": 54.5,
			"UpperToleranceAbsolute": 54.5,
			"VarDescription": "Var 1"
		}, {
			"$type": "Ibs.Inspection.Model.AcquisitionStepModel, Ibs.Inspection.Model",
			"ACQValue": null,
			"AcqStepCount": 5,
			"AcquisitionStepNo": 1,
			"AcquisitionStepNoInGroup": 1,
			"AcquisitionTimestamp": "0001-01-01T00:00:00",
			"AcquisitionType": 1,
			"AcquisitionUser": null,
			"AcquisitionUserID": 0,
			"AmountOfParts": 0,
			"CharacteristicID": 7001,
			"CharacteristicRevision": 1,
			"CharacteristicSpecificationNo": 1,
			"CharacteristicType": 1,
			"ChartValue": "<div class = 'line-color-notdone' ></div>",
			"ControlChartTypeID": 1,
			"DateOfSample": "0001-01-01T00:00:00",
			"DecimalPlaces": 4,
			"DefectCount": null,
			"DefectID": 0,
			"DefectIndex": 0,
			"DefectNo": null,
			"DefectText": null,
			"DerivedFromGroupPlan": false,
			"Description": "Var 1",
			"FailDefinition": "",
			"IO": null,
			"InspectionOrderID": 1001,
			"InspectionOrderSequence": 1,
			"InspectionOrderStepID": 1001,
			"InspectionPlanRevisionID": 4,
			"InspectionSequence": 0,
			"InspectionSequenceType": 0,
			"InspectionStepID": 4001,
			"InspectionType": 4,
			"LowerTolerance": 45.5,
			"LowerToleranceAbsolute": 45.5,
			"Measurement": null,
			"NIO": null,
			"NominalValue": 50,
			"PartNo": 1,
			"PassDefinition": "",
			"PropertyDescription": "Var 1",
			"PropertyNo": "MCT 10",
			"SampleSize": 5,
			"SortingNo": 1,
			"StationID": 0,
			"StationNo": null,
			"ToolID": 1,
			"ToolText": "",
			"UniqueID": 5,
			"UpperTolerance": 54.5,
			"UpperToleranceAbsolute": 54.5,
			"VarDescription": "Var 1"
		}],
		"AdditionalAcquisitionData": null,
		"CharDesc": "Var 1",
		"Chart": "<div class = 'line-color-notdone' ></div>",
		"CountOfAcquisitionSteps": 5,
		"GroupIndex": 1,
		"InspectionOrderStepId": 1001,
		"Type": 1,
		"Value": null
	}, 
	{
		"$type": "Ibs.Inspection.Model.AcquisitionGroupModel, Ibs.Inspection.Model",
		"AcqStatus": "No",
		"AcquisitionSteps": [{
			"$type": "Ibs.Inspection.Model.AcquisitionStepModel, Ibs.Inspection.Model",
			"ACQValue": null,
			"AcqStepCount": 1,
			"AcquisitionStepNo": 6,
			"AcquisitionStepNoInGroup": 1,
			"AcquisitionTimestamp": "0001-01-01T00:00:00",
			"AcquisitionType": 1,
			"AcquisitionUser": null,
			"AcquisitionUserID": 0,
			"AmountOfParts": 1,
			"CharacteristicID": 1001,
			"CharacteristicRevision": 0,
			"CharacteristicSpecificationNo": 1,
			"CharacteristicType": 2,
			"ChartValue": "<div class = 'line-color-notdone' ></div>",
			"ControlChartTypeID": 7,
			"DateOfSample": "0001-01-01T00:00:00",
			"DecimalPlaces": 4,
			"DefectCount": null,
			"DefectID": 0,
			"DefectIndex": 0,
			"DefectNo": null,
			"DefectText": null,
			"DerivedFromGroupPlan": false,
			"Description": "Att 1",
			"FailDefinition": "Fehlerhaft",
			"IO": null,
			"InspectionOrderID": 1001,
			"InspectionOrderSequence": 1,
			"InspectionOrderStepID": 2001,
			"InspectionPlanRevisionID": 4,
			"InspectionSequence": 0,
			"InspectionSequenceType": 0,
			"InspectionStepID": 5001,
			"InspectionType": 4,
			"LowerTolerance": 0,
			"LowerToleranceAbsolute": 0,
			"Measurement": null,
			"NIO": null,
			"NominalValue": 0,
			"PartNo": 1,
			"PassDefinition": "in Ordnung",
			"PropertyDescription": "Att 1",
			"PropertyNo": "MCT 01",
			"SampleSize": 5,
			"SortingNo": 0,
			"StationID": 0,
			"StationNo": null,
			"ToolID": 1,
			"ToolText": "",
			"UniqueID": 6,
			"UpperTolerance": 0,
			"UpperToleranceAbsolute": 0,
			"VarDescription": "Att 1"
		}],
		"AdditionalAcquisitionData": null,
		"CharDesc": "Att 1",
		"Chart": "<div class = 'line-color-notdone' ></div>",
		"CountOfAcquisitionSteps": 1,
		"GroupIndex": 2,
		"InspectionOrderStepId": 2001,
		"Type": 2,
		"Value": null
	}, 
	{
		"$type": "Ibs.Inspection.Model.AcquisitionGroupModel, Ibs.Inspection.Model",
		"AcqStatus": "No",
		"AcquisitionSteps": [{
			"$type": "Ibs.Inspection.Model.AcquisitionStepModel, Ibs.Inspection.Model",
			"ACQValue": null,
			"AcqStepCount": 3,
			"AcquisitionStepNo": 7,
			"AcquisitionStepNoInGroup": 1,
			"AcquisitionTimestamp": "0001-01-01T00:00:00",
			"AcquisitionType": 1,
			"AcquisitionUser": null,
			"AcquisitionUserID": 0,
			"AmountOfParts": 0,
			"CharacteristicID": 10001,
			"CharacteristicRevision": 2,
			"CharacteristicSpecificationNo": 1,
			"CharacteristicType": 3,
			"ChartValue": "<div class = 'line-color-notdone' ></div>",
			"ControlChartTypeID": 11,
			"DateOfSample": "0001-01-01T00:00:00",
			"DecimalPlaces": 4,
			"DefectCount": null,
			"DefectID": 1001,
			"DefectIndex": 0,
			"DefectNo": "FE-967003",
			"DefectText": "Engineblock is in the wrong Position",
			"DerivedFromGroupPlan": false,
			"Description": "Engineblock is in the wrong Position",
			"FailDefinition": "",
			"IO": null,
			"InspectionOrderID": 1001,
			"InspectionOrderSequence": 1,
			"InspectionOrderStepID": 3001,
			"InspectionPlanRevisionID": 4,
			"InspectionSequence": 0,
			"InspectionSequenceType": 0,
			"InspectionStepID": 6001,
			"InspectionType": 4,
			"LowerTolerance": 0,
			"LowerToleranceAbsolute": 0,
			"Measurement": null,
			"NIO": null,
			"NominalValue": 0,
			"PartNo": 1,
			"PassDefinition": "",
			"PropertyDescription": "Vis 1",
			"PropertyNo": "MCT 777",
			"SampleSize": 15,
			"SortingNo": 0,
			"StationID": 0,
			"StationNo": null,
			"ToolID": 1,
			"ToolText": "",
			"UniqueID": 7,
			"UpperTolerance": 0,
			"UpperToleranceAbsolute": 0,
			"VarDescription": "VIS 1"
		}, {
			"$type": "Ibs.Inspection.Model.AcquisitionStepModel, Ibs.Inspection.Model",
			"ACQValue": null,
			"AcqStepCount": 3,
			"AcquisitionStepNo": 7,
			"AcquisitionStepNoInGroup": 1,
			"AcquisitionTimestamp": "0001-01-01T00:00:00",
			"AcquisitionType": 1,
			"AcquisitionUser": null,
			"AcquisitionUserID": 0,
			"AmountOfParts": 0,
			"CharacteristicID": 10001,
			"CharacteristicRevision": 2,
			"CharacteristicSpecificationNo": 1,
			"CharacteristicType": 3,
			"ChartValue": "<div class = 'line-color-notdone' ></div>",
			"ControlChartTypeID": 11,
			"DateOfSample": "0001-01-01T00:00:00",
			"DecimalPlaces": 4,
			"DefectCount": null,
			"DefectID": 1001,
			"DefectIndex": 0,
			"DefectNo": "FE-967003",
			"DefectText": "Engineblock is in the wrong Position",
			"DerivedFromGroupPlan": false,
			"Description": "Engineblock is in the wrong Position",
			"FailDefinition": "",
			"IO": null,
			"InspectionOrderID": 1001,
			"InspectionOrderSequence": 1,
			"InspectionOrderStepID": 3001,
			"InspectionPlanRevisionID": 4,
			"InspectionSequence": 0,
			"InspectionSequenceType": 0,
			"InspectionStepID": 6001,
			"InspectionType": 4,
			"LowerTolerance": 0,
			"LowerToleranceAbsolute": 0,
			"Measurement": null,
			"NIO": null,
			"NominalValue": 0,
			"PartNo": 1,
			"PassDefinition": "",
			"PropertyDescription": "Vis 1",
			"PropertyNo": "MCT 777",
			"SampleSize": 15,
			"SortingNo": 0,
			"StationID": 0,
			"StationNo": null,
			"ToolID": 1,
			"ToolText": "",
			"UniqueID": 8,
			"UpperTolerance": 0,
			"UpperToleranceAbsolute": 0,
			"VarDescription": "VIS 1"
		}, {
			"$type": "Ibs.Inspection.Model.AcquisitionStepModel, Ibs.Inspection.Model",
			"ACQValue": null,
			"AcqStepCount": 3,
			"AcquisitionStepNo": 7,
			"AcquisitionStepNoInGroup": 1,
			"AcquisitionTimestamp": "0001-01-01T00:00:00",
			"AcquisitionType": 1,
			"AcquisitionUser": null,
			"AcquisitionUserID": 0,
			"AmountOfParts": 0,
			"CharacteristicID": 10001,
			"CharacteristicRevision": 2,
			"CharacteristicSpecificationNo": 1,
			"CharacteristicType": 3,
			"ChartValue": "<div class = 'line-color-notdone' ></div>",
			"ControlChartTypeID": 11,
			"DateOfSample": "0001-01-01T00:00:00",
			"DecimalPlaces": 4,
			"DefectCount": null,
			"DefectID": 1001,
			"DefectIndex": 0,
			"DefectNo": "FE-967003",
			"DefectText": "Engineblock is in the wrong Position",
			"DerivedFromGroupPlan": false,
			"Description": "Engineblock is in the wrong Position",
			"FailDefinition": "",
			"IO": null,
			"InspectionOrderID": 1001,
			"InspectionOrderSequence": 1,
			"InspectionOrderStepID": 3001,
			"InspectionPlanRevisionID": 4,
			"InspectionSequence": 0,
			"InspectionSequenceType": 0,
			"InspectionStepID": 6001,
			"InspectionType": 4,
			"LowerTolerance": 0,
			"LowerToleranceAbsolute": 0,
			"Measurement": null,
			"NIO": null,
			"NominalValue": 0,
			"PartNo": 1,
			"PassDefinition": "",
			"PropertyDescription": "Vis 1",
			"PropertyNo": "MCT 777",
			"SampleSize": 15,
			"SortingNo": 0,
			"StationID": 0,
			"StationNo": null,
			"ToolID": 1,
			"ToolText": "",
			"UniqueID": 9,
			"UpperTolerance": 0,
			"UpperToleranceAbsolute": 0,
			"VarDescription": "VIS 1"
		}],
		"AdditionalAcquisitionData": null,
		"CharDesc": "Vis 1",
		"Chart": "<div class = 'line-color-notdone' ></div>",
		"CountOfAcquisitionSteps": 3,
		"GroupIndex": 3,
		"InspectionOrderStepId": 3001,
		"Type": 3,
		"Value": null
	}];
}

//bootstrap(AppComponent);



