﻿import { Injectable } from '@angular/core'
import { AcquisitionGroupModel, AcquisitionStepModel, CharacteristicType } from '../model/acquisitionGroup.model'

@Injectable()
export class IteratorService {

    /**
     * Gets parent of given step row id.
     * @param data
     * @param rowID
     */
    getParent(groups: Array<AcquisitionGroupModel>, rowID: number): AcquisitionGroupModel {

        let grp: AcquisitionGroupModel = null;
        groups.forEach((group, i, arr) => {
            if (null == grp) {
                let matchingSteps = group.AcquisitionSteps.filter((step, i, arr) => step.UniqueID == rowID);
                if (matchingSteps.length > 0) {
                    grp = group;
                }
            }
        });
        return grp;        
    }

    /**
     * Gets child of with given step id.
     * @param data
     * @param inspectionStepID
     */
    getChild(group: AcquisitionGroupModel, inspectionStepID: number): AcquisitionStepModel {

        let matchingSteps = group.AcquisitionSteps.filter((step, i, arr) => step.UniqueID == inspectionStepID);
        return matchingSteps.length == 0 ? null : matchingSteps[0];        
    }

    /**
     * Gets all children of given parent row id.
     * @param data
     * @param parentRowID
     */
    getAllChildData(groups: Array<AcquisitionGroupModel>, parentRowID: number): AcquisitionStepModel[] {
        return groups[parentRowID].AcquisitionSteps;
    }

    /**
     * Gets acquisition step for given step ID.
     * @param groups
     * @param stepId
     */
    getAcquisitionStep(groups: Array<AcquisitionGroupModel>, stepId: number): AcquisitionStepModel {

        let step: AcquisitionStepModel = null;
        groups.forEach((group, i, arr) => {
            if (null == step) {
                let matchingSteps = group.AcquisitionSteps.filter((step, i, arr) => step.UniqueID == stepId);
                if (matchingSteps.length > 0) {
                    step = matchingSteps[0];
                }
            }
        });
        return step;
    }

    /**
     * Gets property name depending on type of acquisition.
     * @param step
     */
    getAcquisitionPropertyName(step: AcquisitionStepModel): string {
        let propertyName = null;
        switch (step.CharacteristicType) {
            case CharacteristicType.VAR:
                propertyName = "ACQValue";
                break;
            case CharacteristicType.ATT:
                propertyName = "NIO";
                break;
            case CharacteristicType.VIS:
                propertyName = "DefectCount";
                break;
            default:
                break;
        }

        return propertyName;
    }
}